HilbertRDA
==========

.. currentmodule:: xeofs.cross

.. autoclass:: HilbertRDA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HilbertRDA.__init__
      ~HilbertRDA.components
      ~HilbertRDA.components_amplitude
      ~HilbertRDA.components_phase
      ~HilbertRDA.compute
      ~HilbertRDA.correlation_coefficients_X
      ~HilbertRDA.correlation_coefficients_Y
      ~HilbertRDA.cross_correlation_coefficients
      ~HilbertRDA.deserialize
      ~HilbertRDA.fit
      ~HilbertRDA.fraction_variance_X_explained_by_X
      ~HilbertRDA.fraction_variance_Y_explained_by_X
      ~HilbertRDA.fraction_variance_Y_explained_by_Y
      ~HilbertRDA.get_params
      ~HilbertRDA.get_serialization_attrs
      ~HilbertRDA.heterogeneous_patterns
      ~HilbertRDA.homogeneous_patterns
      ~HilbertRDA.inverse_transform
      ~HilbertRDA.load
      ~HilbertRDA.predict
      ~HilbertRDA.save
      ~HilbertRDA.scores
      ~HilbertRDA.scores_amplitude
      ~HilbertRDA.scores_phase
      ~HilbertRDA.serialize
      ~HilbertRDA.squared_covariance_fraction
      ~HilbertRDA.transform
   
   

   
   
   